@@ -7,6 +7,7 @@ from django.db import connection
 from slumber.operations import ModelOperation
 from slumber.operations.instancedata import instance_data
 from slumber.server.http import require_permission
+from slumber.server.json import to_json_data
 
 
 class CreateInstance(ModelOperation):
@@ -20,15 +21,28 @@ class CreateInstance(ModelOperation):
             """Use an inner function so that we can generate a proper
             permission name at run time.
             """
+            key_name = self.model.model._meta.pk.name
+            if not request.POST.has_key(key_name):
+                created = True
+            else:
+                filter_args = {key_name: request.POST[key_name]}
+                objects = self.model.model.objects
+                created = (objects.filter(**filter_args).count() == 0)
+
             instance = self.model.model(**dict([(k, v)
                 for k, v in request.POST.items()]))
             instance.save()
+
             # Reset the sequence point in case there was a PK set
             cursor = connection.cursor()
             lines = connection.ops.sequence_reset_sql(
                 no_style(), [self.model.model])
             cursor.execute(';'.join(lines))
-            # Return the
-            return instance_data(response, self.model, instance)
+
+            instance_data(response, self.model, instance)
+            response['pk'] = to_json_data(self.model, instance, 'pk',
+                self.model.fields[key_name])
+            response['created'] = created
+
         return do_create(self, request)
 
